@@ -20,6 +20,7 @@ import sys
 from codecs import BOM_UTF8, BOM_UTF16, BOM_UTF16_BE, BOM_UTF16_LE
 
 import six
+from _version import __version__
 
 # imported lazily to avoid startup performance hit if it isn't used
 compiler = None
@@ -2058,7 +2059,7 @@ class ConfigObj(Section):
             this_entry = section[entry]
             comment = self._handle_comment(section.inline_comments[entry])
             
-            if isinstance(this_entry, dict):
+            if isinstance(this_entry, Section):
                 # a section
                 out.append(self._write_marker(
                     indent_string,
@@ -2117,10 +2118,10 @@ class ConfigObj(Section):
         if outfile is not None:
             outfile.write(output)
         else:
-            h = open(self.filename, 'w')
-            h.write(output)
-            h.close()
-
+            with open(self.filename, 'wb') as h:
+                h.write(output.encode(self.encoding or
+                                      self.default_encoding or
+                                      'ascii'))
 
     def validate(self, validator, preserve_errors=False, copy=False,
                  section=None):
